==> reuse-4.3.4.tgz: reuse/source/win32/os_rgetlastname.c <==
/* -*- mode:c -*- */
/* $Id: os_rgetlastname.c 369 2004-09-11 06:13:25Z cher $ */

/* Copyright (C) 2004 Alexander Chernov <cher@ispras.ru> */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */

#define __REUSE__ 1

/* internal include directives */
#include "lconfig.h"
#include "reuse/config.h"
#include "embed_version.h"

/* reuse include directives */
#include <reuse/osdeps.h>

#include <string.h>

#define NOT_IMPLEMENTED() SWERR(("Not implemented"))

/**
 * NAME:    os_rGetBasename
 * PURPOSE: get basename of the file
 * ARGS:    path   - path of the file
 *          out    - the output buffer
 *          maxlen - size of the output buffer
 * RETURN:  strlen of the basename
 */
int
os_rGetBasename(char const *path, char *out, int maxlen)
{
  NOT_IMPLEMENTED();
#if 0
  int   l;
  char const *s;
  char const *sp = 0;

  if (maxlen <= 0 || !out) return 0;
  out[0] = 0;
  if (maxlen == 1 || !path) return 0;

  l = strlen(path);
  s = path + l - 1;
  for (s = path + l - 1; s >= path; s--) {
    if (*s == '/' || *s == '\\') {
      s++;
      break;
    } else if (*s == '.' && !sp) {
      sp = s;
    } else if (*s == ':') {
      s++;
      break;
    }
  }
  if (s < path) {
    s = path;
  }
  if (s == sp || !sp) {
    sp = path + l;
  }
  l = sp - s;
  if (l > maxlen) l = maxlen;
  strncpy(out, s, l);
  out[maxlen - 1] = 0;
  return strlen(out);
#endif
}

#if REUSE_COMPILE_CVSID - 0 != 0
static char const rcsid [] =
"$Id: os_rgetlastname.c 369 2004-09-11 06:13:25Z cher $";
#endif /* REUSE_COMPILE_CVSID */

/*
 * Local variables:
 *  compile-command: "make -C ../.."
 * End:
 */

==> reuse-4.3.8.tgz: reuse/source/win32/os_rgetlastname.c <==
/* -*- mode:c -*- */
/* $Id: os_rgetlastname.c 532 2008-12-24 15:05:44Z cher $ */

/* Copyright (C) 2004-2008 Alexander Chernov <cher@ejudge.ru> */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */

#define __REUSE__ 1

/* internal include directives */
#include "lconfig.h"
#include "reuse/config.h"
#include "embed_version.h"

/* reuse include directives */
#include <reuse/osdeps.h>

#include <string.h>

/**
 * NAME:    os_rGetLastname
 * PURPOSE: get the last component of the file path
 * ARGS:    path   - path of the file
 *          out    - the output buffer
 *          maxlen - size of the output buffer
 * RETURN:  strlen of the lastname
 */
int
os_rGetLastname(char const *path, char *out, int maxlen)
{
  int len, i, cpsz;

  if (!path || !out || maxlen <= 0) return 0;

  len = strlen(path);
  for (i = len - 1;
       i >= 0 && path[i] && path[i] != '/' && path[i] != '\\' && path[i] != ':';
       --i);
  i++;
  cpsz = len - i;
  if (cpsz + 1 > maxlen) cpsz = maxlen - 1;
  memcpy(out, path + i, cpsz);
  out[cpsz] = 0;
  return cpsz;
}

#if REUSE_COMPILE_CVSID - 0 != 0
static char const rcsid [] =
"$Id: os_rgetlastname.c 532 2008-12-24 15:05:44Z cher $";
#endif /* REUSE_COMPILE_CVSID */

/*
 * Local variables:
 *  compile-command: "make -C ../.."
 * End:
 */
